Приложение A. Описание параметров командной строки
Пред. |  | След.

## Приложение A. Описание параметров командной строки

Интерфейс ко всем функциям предоставляет программа ardj. Эта программа первым параметром принимает имя команды, которое может сопровождаться дополнительными параметрами. Все команды и возможные параметры описаны в этом разделе.

При использовании оболочек bash и zsh работает автодополнение команд и параметров, можно использовать кнопку TAB для ускоренного набора.

`add-incoming-tracks`

  Ищет файлы в папке, указанной в параметре `incoming_path` конфигурационного файла. Все найденные файлы с расширениями `.mp3` и `.ogg` перемещаются в медиатеку и удаляются. Если файл не может быть удалён — он игнорируется (чтобы не добавлять его повторно при каждом последующем вызове).

  Эта команда является эквивалентом команды upload джаббера.

`config`

  Запускает текстовый редактор с открытым для редактирования конфигурационным файлом.

`console [jid]`

  Открывает интерактивную консоль, эмулирующую общение через джаббер (только без джаббера и вообще без использования сети). Эта функция полезна для отладки, например, когда пользователь жалуется на неожиданное поведение команды, которое не воспроизводится у других пользователей.

`db-console`

  Открывает интерактивную консоль для работы с базой данных, SQLite или MySQL. Может использоваться в скриптах (запросы надо передавать через stdin).

`db-init`

  Инициализация недостающих таблиц и индексов базы данных. Эта процедура обычно выполняется при установке пакета и больше не нужна. Выполнить её вручную может понадобиться, например, если вы случайно уничтожили базу данных и хотите начать сначала.

`db-purge`

  Удаляет из базы данных мусор, вроде неиспользуемых меток и файлов, относящихся к дорожкам, которые были удалены.

`db-stats`

  Показывает информацию о количестве композиций и их суммарной продолжительности, например: "2883 tracks, 192.0 hours".

`download-artist name`

  Сохраняет запрос на загрузку песен указанного исполнителя. Сама загрузка выполняется позже, в фоновом режиме.

  Эта команда является эквивалентом команды download джаббера.

`export-total-listeners`

  Выводит в stdout общую статистику прослушиваний.

`export-yesterday-listeners`

  Выводит в stdout подробную статистику прослушиваний за последние сутки.

`find-new-tracks`

  Запускает поиск новой музыки. Сначала выбираются исполнители, имеющие дорожки с оценками выше средней, затем в Last.fm и Jamendo ищется новая музыка этих исполнителей, которую позволено скачивать.

`fix-artist-names`

  Проверяет имя исполнителя по базе данных Last.fm и исправляет, если сервер рекомендует это. Обычно это приводит к изменению регистра, но может и полностью заменить имя, например, исправив ложную транслитерацию.

`help`

  Выводит краткую сводку по поддерживаемым командам.

`mark-hitlist`

  Отмечает примерно десяток лучших песен меткой "hitlist". Реальное количество дорожек обычно чуть больше, потому что отмечаются все дорожки с рейтингом не ниже десятой по счёту (то есть на десятом месте может быть несколько дорожек).

  Если настроено взаимодействие с Last.fm, отмеченные дорожки добавляются в «любимые».

`mark-liked-by label jid1 jid2 ...`

  Отмечает меткой "label" композиции, которые нравятся всем указанным пользователям. Эту команду можно использовать для создания специфической атмосферы перед прямыми включениями, когда известны будущие участники.

`mark-long`

  Отмечает меткой "long" композиции с продолжительностью выше средней. Можно использовать метку для исключения слишком длинных песен из дневной ротации.

`mark-orphans`

  Отмечает меткой "orphan" композиции, не находящиеся ни в одном плейлисте.

`merge-votes`

  Склеивает голоса пользователей в соответствии со значением параметра `jabber_aliases` конфигурационного файла.

`queue-flush`

  Очищает очередь заказов.

`scan-replaygain [files...]`

  Запускает сканирование ReplayGain для всех файлов, у которых нет нужной информации. Если параметр `files` не указан — сканирует все файлы в медиатеке.

  Для сканирования используются программы mp3gain и vorbisgain.

`serve`

  Запускает веб-сервер для доступа к Web API. Сервер обычно доступен по адресу localhost:8080, но этот адрес может быть изменён параметром `api_socket` конфигурационного файла. Сервер используется плагином для ices и некоторыми командами джаббера.

  Запускать сервер вручную может понадобиться только в отладочных целях. В повседневной работе его запускает системная служба, ещё это можно сделать командой sudo start ardj-server (по умолчанию команда доступна без пароля всем пользователям из группы "ardj").

`tags files...`

  Выводит содержимое поддерживаемых тэгов. Эта функция обычно используется в отладочных целях, чтобы убедиться в работоспособности функции чтения тэгов и в корректности самих тэгов. Для работы используется библиотека python-mutagen.

`twit "text..."`

  Отправляет указанный текст в Твиттер. Работает только при корректном заполнении параметра `twitter` конфигурационного файла, в противном случае пишет что делать.

`twit-replies`

  Выводит сообщения, отправленные на имя используемой учётной записи. Предположительно бесполезная функция.

`update-schedule`

  Собирает на Last.fm информацию о предстоящих концертах интересных исполнителей (имеющих дорожки с оценками выше средней) и сохраняет её в файл типа JavaScript, указанный в параметре `event_schedule_path` конфигурационного файла; этот файл можно использовать для вывода карты на сайте.

  Работает только при корректной настройке взаимодействия с Last.fm.

`update-track-lengths`

  Сверяет продолжительность файлов с информацией из базы данных и корректирует её. Полезно запускать после ручного вмешательства в медиатеку.

`update-track-weights`

  Сдвигает текущий рейтинг каждой дорожки к реальному. Вредная функция; описанная процедура выполняется автоматически при каждом проигрывании, ручной запуск только сбивает рейтинги.

`xmpp-send "message text" [jid]`

  Отправляет сообщение указанному пользователю или в чат, если пользователь не указан (название комнаты указывается в параметре `jabber_chat_room` конфигурационного файла).

Пред. |  | След.
api/track/info.json | Начало | Приложение B. Описание команд jabber-бота